Package: agilp
Type: Package
Title: Agilent expression array processing package
Version: 3.44.0
Date: 2012-06-10
Author: Benny Chain <b.chain@ucl.ac.uk>
Maintainer: Benny Chain <b.chain@ucl.ac.uk>
Depends: R (>= 2.14.0)
Description: More about what it does (maybe more than one line)
License: GPL-3
Packaged: 2026-04-28 20:32:16 UTC; biocbuild
git_url: https://git.bioconductor.org/packages/agilp
git_branch: RELEASE_3_23
git_last_commit: 3c7a692
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
